{% extends "epic/base_layout.html" %}
{% load crispy_forms_tags %}

{% block buttons %}
  <a class="btn btn-default" href="{% url 'epic:epic_index' %}">
    Up <i class="glyphicon glyphicon-chevron-up"></i>
  </a>

  <a class="btn btn-default" href="{% url 'epic:warehouse_add' %}">
    Add New Warehouse <i class="glyphicon glyphicon-plus"></i>
  </a>

  <a class="btn btn-default" href="{% url 'epic:warehouse_stock_all' %}">
    View Stock for all Warehouses <i class="glyphicon glyphicon-list"></i>
  </a>
{% endblock buttons %}

{% block content %}
{{ block.super }}

<div class="panel panel-default">
  <div class="panel-heading">Existing Warehouses</div>
  <div class="panel-body">
    {{ list_pager|safe }}
    <ul>
      {% for warehouse in warehouse_list %}
      <li>{{ warehouse.html_link|safe }}</li>
      {% endfor %}
    </ul>
  </div>
</div>

{% endblock content %}
